@@ -44,14 +44,13 @@ $navigationEntry = function () use ($c) {
 $c->getServer()->getNavigationManager()->add($navigationEntry);
 
 //Script for registering file actions
-$request = \OC::$server->getRequest();
-if (isset($request->server['REQUEST_URI'])) {
-	$url = $request->server['REQUEST_URI'];
-
-	if (preg_match('%index.php/apps/files(/.*)?%', $url)) {
+$eventDispatcher = \OC::$server->getEventDispatcher();
+$eventDispatcher->addListener(
+	'OCA\Files::loadAdditionalScripts',
+	function() {
 		\OCP\Util::addScript('documents', 'viewer/viewer');
 	}
-}
+);
 
 if ($c->query('AppConfig')->isConverterEnabled()){
 	$docFilter = new Office(
