@@ -674,13 +674,6 @@ FileList.getCurrentDirectory = function(){
 	return $('#dir').val() || '/';
 };
 
-FileList.setViewerMode = function(){
-};
-FileList.findFile = function(fileName){
-	fullPath = escapeHTML(FileList.getCurrentDirectory + '/' + fileName);
-	return !!$('.documentslist .document:not(.template,.progress) a[original-title="' + fullPath + '"]').length
-}
-
 $(document).ready(function() {
 	documentsMain.docs = $('.documentslist').documentGrid();
 	documentsMain.overlay = $('<div id="documents-overlay" class="icon-loading"></div><div id="documents-overlay-below" class="icon-loading-dark"></div>').documentOverlay();
@@ -702,10 +695,6 @@ $(document).ready(function() {
 	
 	$('.add-document').on('click', '.add', documentsMain.onCreate);
 
-	OC.Upload._isReceivedSharedFile = function () {
-		return false;
-	}
-
 	var file_upload_start = $('#file_upload_start');
 	if (typeof supportAjaxUploadWithProgress !== 'undefined' && supportAjaxUploadWithProgress()) {
 		file_upload_start.on('fileuploadstart', function(e, data) {
