@@ -2,13 +2,14 @@ OC.L10N.register(
     "documents",
     {
     "Documents" : "اسناد",
-    "Can't create document" : "امکان ایجاد مستند وجود ندارد",
+    "Can't create document" : "امکان ایجاد این سند وجود ندارد",
     "You don't have permission to rename this document" : "شما دسترسی مجاز برای تغییر نام این سند را ندارید",
     "Directory saved successfully." : "پوشه با موفقیت ذخیره شد.",
     "An error occurred while changing directory." : "یک خطا در حین تغییر پوشه رخ داده است.",
     "Saved" : "ذخیره شد",
     "Saving..." : "در حال ذخیره سازی...",
     "Failed to load documents." : "فراخوانی اسناد با شکست مواجه شد",
+    "No documents were found. Upload or create a document to get started!" : "هیچ سندی یافت نشد. برای شروع سندی ساخته یا آپلود کنید! ",
     "No connection to server. Trying to reconnect." : "هیچگونه ارتباط به سرور موجود نمی‌باشد. لطفاً ارتباط مجدد برقرار کنید.",
     "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "خروج از این صفحه در مود ویرایش باعث از دست دادن اطلاعات ذخیر نشده خواهد شد. پیشنهاد می‌شود بجای آن که از دکمه‌ی 'خروج' استفاده فرمایید.",
     "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "فراخوانی این سند با مشکل مواجه شد. لطفاً بررسی نمایید که آیا می‌توان آن را با یک برنامه‌ی ویرایشگر odt خارجی باز نمود. البته این اشکال ممکن است بخاطر حذف شدن یا حذف اشتراک گذاری آن نیز اتفاق افتاده باشد",
@@ -26,6 +27,8 @@ OC.L10N.register(
     "Bottom" : "پایین",
     "Cancel" : "منصرف شدن",
     "Center" : "وسط",
+    "Clone" : "شبیه سازی",
+    "Clone this Style" : "شبیه سازی این استایل",
     "Close" : "بستن",
     "Color" : "رنگ",
     "Create" : "ایجاد کردن",
@@ -40,6 +43,8 @@ OC.L10N.register(
     "Insert Image" : "درج تصویر",
     "Invite Members" : "دعوت کردن اعضا",
     "Italic" : "کج نویس",
+    "Justified" : "متقارن شد",
+    "Justify" : "متقارن",
     "Left" : "چپ",
     "Loading" : "بارگذاری",
     "Members" : "اعضا",
@@ -105,10 +110,13 @@ OC.L10N.register(
     "Warning" : "اخطار",
     "Edit" : "ویرایش",
     "guest" : "میهمان",
+    "MS Word support (requires openOffice/libreOffice)" : "پشتیبانی از ماکروسافت ورد(نیازمند لیبره آفیس/ اپن آفیس)",
     "Local" : "محلی",
+    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "اپن افیس/لیبره آفیس بر روی این سرور نصب شده اند. مسیر دسترسی به کد باینری از طریق preview_libreoffice_path in config.phpموجود می‌باشد. ",
     "External" : "خارجی",
     "Disabled" : "غیرفعال شده",
     "No MS Word support" : "عدم پشتیبانی از MS Word",
+    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
     "Server URL" : "URL سرور",
     "Apply and test" : "اعمال و تست",
     "New document" : "سند جدید",
